@@ -6,11 +6,7 @@
 
 from tornado.options import options
 
-from lesscode.db.elasticsearch_helper import ElasticsearchHelper
-from lesscode.db.mongodb_helper import MongodbHelper
-from lesscode.db.mysql_helper import MysqlHelper
 from lesscode.db.base_sql_helper import BaseSqlHelper
-from lesscode.db.postgresql_helper import PostgresqlHelper
 from lesscode.db.condition_wrapper import ConditionWrapper
 
 
@@ -26,13 +22,24 @@ class DSHelper(BaseSqlHelper):
         """
         self.pool, self.dialect = options.database[pool_name]
         if self.dialect == "postgresql":
-            self.db_helper = PostgresqlHelper(self.pool)
+            # self.db_helper = PostgresqlHelper(self.pool)
+            clazz = getattr(__import__("lesscode.db.postgresql.postgresql_helper", fromlist="PostgresqlHelper"),
+                            "PostgresqlHelper")
         elif self.dialect == "mysql":
-            self.db_helper = MysqlHelper(self.pool)
+            # self.db_helper = MysqlHelper(self.pool)
+            clazz = getattr(__import__("lesscode.db.mysql.mysql_helper", fromlist="MysqlHelper"), "MysqlHelper")
+            # 执行用例
+            self.db_helper = clazz(self.pool)
         elif self.dialect == "mongodb":
-            self.db_helper = MongodbHelper(self.pool)
+            clazz = getattr(__import__("lesscode.db.mongodb.mongodb_helper", fromlist="MongodbHelper"), "MongodbHelper")
+            # self.db_helper = MongodbHelper(self.pool)
         elif self.dialect == "elasticsearch":
-            self.db_helper = ElasticsearchHelper(self.pool)
+            clazz = getattr(
+                __import__("lesscode.db.elasticsearch.elasticsearch_helper", fromlist="ElasticsearchHelper"),
+                "ElasticsearchHelper")
+            # self.db_helper = ElasticsearchHelper(self.pool)
+        if clazz:
+            self.db_helper = clazz(self.pool)
 
     async def insert_data(self, table_name: str, data):
         return await self.db_helper.insert_data(table_name, data)
